@@ -1,7 +1,7 @@
 %%%-------------------------------------------------------------------
 %%% Created : 26 Sep 2018 by Evgeny Khramtsov <ekhramtsov@process-one.net>
 %%%
-%%% Copyright (C) 2002-2020 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2021 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -462,7 +462,11 @@ stop_test() ->
 %%%===================================================================
 test_dir() ->
     {ok, Cwd} = file:get_cwd(),
-    filename:join(filename:dirname(Cwd), "test").
+    CwdClean = case lists:reverse(filename:split(Cwd)) of
+                   [".eunit" | Tail] -> Tail; % when using rebar2
+                   Tail -> Tail % when using rebar3
+    end,
+    filename:join(lists:reverse(["test" | CwdClean])).
 
 path(File) ->
     unicode:characters_to_binary(filename:join(test_dir(), File)).
